context_show library

Classes

OverlayCloser
A class that holds the information needed to close an overlay.
OverlayController<T>
A controller that is passed to the overlay builder.
Overlays
A utility class to select overlays to close.
OverlaySafeArea
A class that holds the safe area for the overlay.
Transition
A class that represents a transition.
TransitionBuilders
A utility class that provides a set of transition builders.

Extensions

ContextShow on BuildContext
An extension on BuildContext that provides methods to show and close overlays.
OverlayCloserIterableExtensions on Iterable<OverlayCloser>
An extension on Iterable<OverlayCloser> that provides a byId method.
TransitionExtensions on Transition
An extension that provides a set of transition methods on a Transition.