OverlaySafeArea class

A class that holds the safe area for the overlay.

It is used to avoid the status bar, app bar, and bottom navigation bar.

Constructors

OverlaySafeArea({required double top, required double bottom, required double left, required double right})
Creates an OverlaySafeArea.
const
OverlaySafeArea.of(BuildContext context, {BuildContext? surface})
Creates an OverlaySafeArea from the given context.
factory

Properties

bottom → double
The bottom safe area inset.
final
hashCode → int
The hash code for this object.
no setterinherited
insets → EdgeInsets
The safe area insets.
no setter
left → double
The left safe area inset.
final
The right safe area inset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
The top safe area inset.
final

Methods

forSurface(BuildContext surface) → OverlaySafeArea
Re-expresses these insets relative to surface.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited