Overlays class abstract

A utility class to select overlays to close.

It is used in context.close() to select which overlays to close.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

all({String? id}) Iterable<OverlayCloser> Function(Iterable<OverlayCloser> closers)
A selector that returns all overlays that match the given id.
first({String? id}) OverlayCloser? Function(Iterable<OverlayCloser> closers)
A selector that returns the first overlay that matches the given id.
last({String? id}) OverlayCloser? Function(Iterable<OverlayCloser> closers)
A selector that returns the last overlay that matches the given id.