OverlayCloser class
A class that holds the information needed to close an overlay.
Constructors
-
OverlayCloser(Future<
void> function([Object?]), Type type, String id) -
Creates an OverlayCloser.
const
Properties
-
function
→ Future<
void> Function([Object?]) -
The function that closes the overlay.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The id of the overlay.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Type
-
The type of the result that the overlay returns.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited